@@ -172,6 +172,71 @@ special (void)
   mpfr_clear (t);
 }
 
+static void
+bug20090918 (void)
+{
+  mpfr_t x, y, z;
+  mp_limb_t y0;
+  int inexy, inexz;
+  int r, i;
+  char *s[] = { "61680.352935791015625", "61680.999999" };
+  mp_exp_t emin;
+
+  emin = mpfr_get_emin ();
+  mpfr_init2 (x, 32);
+  mpfr_init2 (y, 13);
+
+  for (i = 0; i <= 9; i++)
+    {
+      mpfr_set_str (x, s[i & 1], 10, GMP_RNDZ);
+
+      RND_LOOP(r)
+        {
+          set_emin ((i >> 1) - 3);
+          inexy = mpfr_frac (y, x, (mpfr_rnd_t) r);
+          set_emin (emin);
+          y0 = MPFR_MANT(y)[0];
+          while (y0 != 0 && (y0 >> 1) << 1 == y0)
+            y0 >>= 1;
+          if (y0 > 0x2000)
+            {
+              printf ("Error in bug20090918 (significand has more than"
+                      " 13 bits), i = %d, %s.\n", i,
+                      mpfr_print_rnd_mode ((mpfr_rnd_t) r));
+              exit (1);
+            }
+          mpfr_init2 (z, 32);
+          inexz = mpfr_frac (z, x, GMP_RNDN);
+          MPFR_ASSERTN (inexz == 0);  /* exact */
+          inexz = mpfr_prec_round (z, 13, (mpfr_rnd_t) r);
+          set_emin ((i >> 1) - 3);
+          inexz = mpfr_check_range (z, inexz, (mpfr_rnd_t) r);
+          set_emin (emin);
+          if (mpfr_cmp0 (y, z) != 0)
+            {
+              printf ("Error in bug20090918, i = %d, %s.\n", i,
+                      mpfr_print_rnd_mode ((mpfr_rnd_t) r));
+              printf ("Expected ");
+              mpfr_dump (z);
+              printf ("Got      ");
+              mpfr_dump (y);
+              exit (1);
+            }
+          if (! SAME_SIGN (inexy, inexz))
+            {
+              printf ("Incorrect ternary value in bug20090918, i = %d, %s.\n",
+                      i, mpfr_print_rnd_mode ((mpfr_rnd_t) r));
+              printf ("Expected %d, got %d.\n", inexz, inexy);
+              exit (1);
+            }
+          mpfr_clear (z);
+        }
+    }
+
+  mpfr_clear (x);
+  mpfr_clear (y);
+}
+
 #define TEST_FUNCTION mpfr_frac
 #include "tgeneric.c"
 
@@ -227,6 +292,8 @@ main (void)
   mpfr_clear (ip);
   mpfr_clear (fp);
 
+  bug20090918 ();
+
   test_generic (2, 1000, 10);
 
   tests_end_mpfr ();
