@@ -1,22 +1,22 @@
 /* Test file for mpfr_pow, mpfr_pow_ui and mpfr_pow_si.
 
-Copyright 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008 Free Software Foundation, Inc.
+Copyright 2000, 2001, 2002, 2003, 2004, 2005, 2006, 2007, 2008, 2009 Free Software Foundation, Inc.
 Contributed by the Arenaire and Cacao projects, INRIA.
 
-This file is part of the MPFR Library.
+This file is part of the GNU MPFR Library.
 
-The MPFR Library is free software; you can redistribute it and/or modify
+The GNU MPFR Library is free software; you can redistribute it and/or modify
 it under the terms of the GNU Lesser General Public License as published by
 the Free Software Foundation; either version 2.1 of the License, or (at your
 option) any later version.
 
-The MPFR Library is distributed in the hope that it will be useful, but
+The GNU MPFR Library is distributed in the hope that it will be useful, but
 WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Lesser General Public
 License for more details.
 
 You should have received a copy of the GNU Lesser General Public License
-along with the MPFR Library; see the file COPYING.LIB.  If not, write to
+along with the GNU MPFR Library; see the file COPYING.LIB.  If not, write to
 the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301, USA. */
 
@@ -56,6 +56,8 @@ test_pow (mpfr_ptr a, mpfr_srcptr b, mpfr_srcptr c, mp_rnd_t rnd_mode)
 
 #define TEST_FUNCTION test_pow
 #define TWO_ARGS
+#define TEST_RANDOM_POS 16
+#define TGENERIC_NOWARNING 1
 #include "tgeneric.c"
 
 #define TEST_FUNCTION mpfr_pow_ui
@@ -345,7 +347,7 @@ check_pow_si (void)
 }
 
 static void
-check_special_pow_si ()
+check_special_pow_si (void)
 {
   mpfr_t a, b;
   mp_exp_t emin;
@@ -421,7 +423,7 @@ check_inexact (mp_prec_t p)
   mpfr_init (y);
   mpfr_init (z);
   mpfr_init (t);
-  mpfr_random (x);
+  mpfr_urandomb (x, RANDS);
   u = randlimb () % 2;
   for (q = 2; q <= p; q++)
     for (rnd = 0; rnd < GMP_RND_MAX; rnd++)
@@ -473,7 +475,7 @@ check_inexact (mp_prec_t p)
 }
 
 static void
-special ()
+special (void)
 {
   mpfr_t x, y, z, t;
   mp_exp_t emin, emax;
@@ -1035,7 +1037,7 @@ x_near_one (void)
 }
 
 static int
-mpfr_pow275 (mpfr_t y, mpfr_t x, mp_rnd_t r)
+mpfr_pow275 (mpfr_ptr y, mpfr_srcptr x, mp_rnd_t r)
 {
   mpfr_t z;
   int inex;
@@ -1286,7 +1288,8 @@ bug20080721 (void)
                   mpfr_print_rnd_mode ((mp_rnd_t) rnd));
           printf ("expected ");
           mpfr_out_str (stdout, 2, 0, t[i], GMP_RNDN);
-          printf (", inex = %d, flags = %u\n", inex0, MPFR_FLAGS_INEXACT);
+          printf (", inex = %d, flags = %u\n", inex0,
+                  (unsigned int) MPFR_FLAGS_INEXACT);
           printf ("got      ");
           mpfr_out_str (stdout, 2, 0, z, GMP_RNDN);
           printf (", inex = %d, flags = %u\n", inex, flags);
