@@ -20,9 +20,7 @@ along with the GNU MPFR Library; see the file COPYING.LIB.  If not, write to
 the Free Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston,
 MA 02110-1301, USA. */
 
-#include <stdio.h>
 #include <stdlib.h>
-#include <string.h> /* for strlen */
 
 #include "mpfr-test.h"
 
